@@ -6,6 +6,7 @@ from sqlalchemy import Numeric
 from sqlalchemy import text
 from sqlalchemy import types as sqltypes
 from sqlalchemy.dialects.postgresql import BIGINT
+from sqlalchemy.dialects.postgresql import ExcludeConstraint
 from sqlalchemy.dialects.postgresql import INTEGER
 from sqlalchemy.sql.expression import ColumnClause
 from sqlalchemy.sql.expression import UnaryExpression
@@ -16,6 +17,7 @@ from .base import alter_table
 from .base import AlterColumn
 from .base import ColumnComment
 from .base import compiles
+from .base import format_column_name
 from .base import format_table_name
 from .base import format_type
 from .base import RenameTable
@@ -29,9 +31,6 @@ from ..operations.base import Operations
 from ..util import compat
 from ..util import sqla_compat
 
-if util.sqla_100:
-    from sqlalchemy.dialects.postgresql import ExcludeConstraint
-
 
 log = logging.getLogger(__name__)
 
@@ -68,19 +67,22 @@ class PostgresqlImpl(DefaultImpl):
         if None in (conn_col_default, rendered_metadata_default):
             return not defaults_equal
 
+        if compat.py2k:
+            # look for a python 2 "u''" string and filter
+            m = re.match(r"^u'(.*)'$", rendered_metadata_default)
+            if m:
+                rendered_metadata_default = "'%s'" % m.group(1)
+
+        # check for unquoted string and quote for PG String types
         if (
-            metadata_column.server_default is not None
+            not isinstance(inspector_column.type, Numeric)
+            and metadata_column.server_default is not None
             and isinstance(
                 metadata_column.server_default.arg, compat.string_types
             )
-            and not re.match(r"^'.+'$", rendered_metadata_default)
-            and not isinstance(inspector_column.type, Numeric)
+            and not re.match(r"^'.*'$", rendered_metadata_default)
         ):
-            # don't single quote if the column type is float/numeric,
-            # otherwise a comparison such as SELECT 5 = '5.0' will fail
-            rendered_metadata_default = re.sub(
-                r"^u?'?|'?$", "'", rendered_metadata_default
-            )
+            rendered_metadata_default = "'%s'" % rendered_metadata_default
 
         return not self.connection.scalar(
             "SELECT %s = %s" % (conn_col_default, rendered_metadata_default)
@@ -184,24 +186,13 @@ class PostgresqlImpl(DefaultImpl):
         metadata_indexes,
     ):
 
-        conn_uniques_by_name = dict(
-            (c.name, c) for c in conn_unique_constraints
-        )
         conn_indexes_by_name = dict((c.name, c) for c in conn_indexes)
 
-        if not util.sqla_100:
-            doubled_constraints = set(
-                conn_indexes_by_name[name]
-                for name in set(conn_uniques_by_name).intersection(
-                    conn_indexes_by_name
-                )
-            )
-        else:
-            doubled_constraints = set(
-                index
-                for index in conn_indexes
-                if index.info.get("duplicates_constraint")
-            )
+        doubled_constraints = set(
+            index
+            for index in conn_indexes
+            if index.info.get("duplicates_constraint")
+        )
 
         for ix in doubled_constraints:
             conn_indexes.remove(ix)
@@ -290,8 +281,10 @@ def visit_column_comment(element, compiler, **kw):
     )
 
     return ddl.format(
-        table_name=element.table_name,
-        column_name=element.column_name,
+        table_name=format_table_name(
+            compiler, element.table_name, element.schema
+        ),
+        column_name=format_column_name(compiler, element.column_name),
         comment=comment,
     )
 
@@ -341,10 +334,6 @@ class CreateExcludeConstraintOp(ops.AddConstraintOp):
         )
 
     def to_constraint(self, migration_context=None):
-        if not util.sqla_100:
-            raise NotImplementedError(
-                "ExcludeConstraint not supported until SQLAlchemy 1.0"
-            )
         if self._orig_constraint is not None:
             return self._orig_constraint
         schema_obj = schemaobj.SchemaObjects(migration_context)
@@ -432,17 +421,15 @@ def _add_exclude_constraint(autogen_context, op):
     return _exclude_constraint(op.to_constraint(), autogen_context, alter=True)
 
 
-if util.sqla_100:
+@render._constraint_renderers.dispatch_for(ExcludeConstraint)
+def _render_inline_exclude_constraint(constraint, autogen_context):
+    rendered = render._user_defined_render(
+        "exclude", constraint, autogen_context
+    )
+    if rendered is not False:
+        return rendered
 
-    @render._constraint_renderers.dispatch_for(ExcludeConstraint)
-    def _render_inline_exclude_constraint(constraint, autogen_context):
-        rendered = render._user_defined_render(
-            "exclude", constraint, autogen_context
-        )
-        if rendered is not False:
-            return rendered
-
-        return _exclude_constraint(constraint, autogen_context, False)
+    return _exclude_constraint(constraint, autogen_context, False)
 
 
 def _postgresql_autogenerate_prefix(autogen_context):
