@@ -1,11 +1,12 @@
 from sqlalchemy.testing import config  # noqa
+from sqlalchemy.testing import emits_warning  # noqa
 from sqlalchemy.testing import engines  # noqa
-from sqlalchemy.testing import exclusions  # noqa
 from sqlalchemy.testing import mock  # noqa
 from sqlalchemy.testing import provide_metadata  # noqa
 from sqlalchemy.testing.config import requirements as requires  # noqa
 
 from alembic import util  # noqa
+from . import exclusions  # noqa
 from .assertions import assert_raises  # noqa
 from .assertions import assert_raises_message  # noqa
 from .assertions import emits_python_deprecation_warning  # noqa
@@ -16,4 +17,7 @@ from .assertions import is_false  # noqa
 from .assertions import is_not_  # noqa
 from .assertions import is_true  # noqa
 from .assertions import ne_  # noqa
+from .fixture_functions import combinations  # noqa
+from .fixture_functions import fixture  # noqa
 from .fixtures import TestBase  # noqa
+from .util import resolve_lambda  # noqa
